diff --git a/osu.Game/Beatmaps/BeatmapManager.cs b/osu.Game/Beatmaps/BeatmapManager.cs
index 8728d776d0..c179821a7c 100644
--- a/osu.Game/Beatmaps/BeatmapManager.cs
+++ b/osu.Game/Beatmaps/BeatmapManager.cs
@@ -249,10 +249,13 @@ namespace osu.Game.Beatmaps
/// Retrieve a instance for the provided
///
/// The beatmap to lookup.
/// The currently loaded . Allows for optimisation where elements are shared with the new beatmap.
/// A instance correlating to the provided .
public WorkingBeatmap GetWorkingBeatmap(BeatmapInfo beatmapInfo, WorkingBeatmap previous = null)
{
+ if (beatmapInfo?.ID > 0 && previous != null && previous.BeatmapInfo?.ID == beatmapInfo.ID)
+ return previous;
+
if (beatmapInfo?.BeatmapSet == null || beatmapInfo == DefaultBeatmap?.BeatmapInfo)
return DefaultBeatmap;
@@ -249,10 +249,13 @@ namespace osu.Game.Beatmaps
///
/// The beatmap to lookup.
- /// The currently loaded . Allows for optimisation where elements are shared with the new beatmap.
+ /// The currently loaded . Allows for optimisation where elements are shared with the new beatmap. May be returned if beatmapInfo requested matches
/// A instance correlating to the provided .
public WorkingBeatmap GetWorkingBeatmap(BeatmapInfo beatmapInfo, WorkingBeatmap previous = null)